#include <boost/python.hpp>
#include <boost/python/module.hpp>

void __Blob();
void __ChannelType();
void __Color();
void __ColorspaceType();
void __CompositeOperator();
void __CompressionType();
void __Coordinate();
void __DecorationType();
void __DistortImageMethod();
void __Drawable();
void __DrawableAffine();
void __DrawableArc();
void __DrawableBezier();
void __DrawableCircle();
void __DrawableClipPath();
void __DrawableColor();
void __DrawableCompositeImage();
void __DrawableDashArray();
void __DrawableDashOffset();
void __DrawableEllipse();
void __DrawableFillColor();
void __DrawableFillOpacity();
void __DrawableFillRule();
void __DrawableFont();
void __DrawableGravity();
void __DrawableLine();
void __DrawableMatte();
void __DrawableMiterLimit();
void __DrawablePath();
void __DrawablePoint();
void __DrawablePointSize();
void __DrawablePolygon();
void __DrawablePolyline();
void __DrawablePopClipPath();
void __DrawablePopGraphicContext();
void __DrawablePopPattern();
void __DrawablePushClipPath();
void __DrawablePushGraphicContext();
void __DrawablePushPattern();
void __DrawableRectangle();
void __DrawableRotation();
void __DrawableRoundRectangle();
void __DrawableScaling();
void __DrawableSkewX();
void __DrawableSkewY();
void __DrawableStrokeAntialias();
void __DrawableStrokeColor();
void __DrawableStrokeLineCap();
void __DrawableStrokeLineJoin();
void __DrawableStrokeOpacity();
void __DrawableStrokeWidth();
void __DrawableText();
void __DrawableTextAntialias();
void __DrawableTextDecoration();
void __DrawableTextUnderColor();
void __DrawableTranslation();
void __DrawableViewbox();
void __EndianType();
void __Exception();
void __FillRule();
void __FilterTypes();
void __Geometry();
void __GravityType();
void __Image();
void __ImageType();
void __InterlaceType();
void __LineCap();
void __LineJoin();
void __Montage();
void __NoiseType();
void __OrientationType();
void __PaintMethod();
void __PathArcAbs();
void __PathArcArgs();
void __PathArcRel();
void __PathClosePath();
void __PathCurvetoAbs();
void __PathCurvetoArgs();
void __PathCurvetoRel();
void __PathLinetoAbs();
void __PathLinetoHorizontalAbs();
void __PathLinetoHorizontalRel();
void __PathLinetoRel();
void __PathLinetoVerticalAbs();
void __PathLinetoVerticalRel();
void __PathMovetoAbs();
void __PathMovetoRel();
void __PathQuadraticCurvetoAbs();
void __PathQuadraticCurvetoArgs();
void __PathQuadraticCurvetoRel();
void __PathSmoothCurvetoAbs();
void __PathSmoothCurvetoRel();
void __PathSmoothQuadraticCurvetoAbs();
void __PathSmoothQuadraticCurvetoRel();
void __Pixels();
void __QuantumOperator();
void __QuantumType();
void __RenderingIntent();
void __ResolutionType();
void __SparseColorMethod();
void __StorageType();
void __StretchType();
void __StyleType();
void __STL();
void __TypeMetric();
void __VirtualPixelMethod();
void __VPath();
void __gminfo();

BOOST_PYTHON_MODULE(_pgmagick)
{
    __Blob();
    __ChannelType();
    __Color();
    __ColorspaceType();
    __CompositeOperator();
    __CompressionType();
    __Coordinate();
    __DecorationType();
    __DistortImageMethod();
    __VPath();
    __Drawable();
    __DrawableAffine();
    __DrawableArc();
    __DrawableBezier();
    __DrawableCircle();
    __DrawableClipPath();
    __DrawableColor();
    __DrawableCompositeImage();
    __DrawableDashArray();
    __DrawableDashOffset();
    __DrawableEllipse();
    __DrawableFillColor();
    __DrawableFillOpacity();
    __DrawableFillRule();
    __DrawableFont();
    __DrawableGravity();
    __DrawableLine();
    __DrawableMatte();
    __DrawableMiterLimit();
    __DrawablePath();
    __DrawablePoint();
    __DrawablePointSize();
    __DrawablePolygon();
    __DrawablePolyline();
    __DrawablePopClipPath();
    __DrawablePopGraphicContext();
    __DrawablePopPattern();
    __DrawablePushClipPath();
    __DrawablePushGraphicContext();
    __DrawablePushPattern();
    __DrawableRectangle();
    __DrawableRotation();
    __DrawableRoundRectangle();
    __DrawableScaling();
    __DrawableSkewX();
    __DrawableSkewY();
    __DrawableStrokeAntialias();
    __DrawableStrokeColor();
    __DrawableStrokeLineCap();
    __DrawableStrokeLineJoin();
    __DrawableStrokeOpacity();
    __DrawableStrokeWidth();
    __DrawableText();
    __DrawableTextAntialias();
    __DrawableTextDecoration();
    __DrawableTextUnderColor();
    __DrawableTranslation();
    __DrawableViewbox();
    __EndianType();
    __Exception();
    __FillRule();
    __FilterTypes();
    __Geometry();
    __GravityType();
    __Image();
    __ImageType();
    __InterlaceType();
    __LineCap();
    __LineJoin();
    __Montage();
    __NoiseType();
    __OrientationType();
    __PaintMethod();
    __PathArcAbs();
    __PathArcArgs();
    __PathArcRel();
    __PathClosePath();
    __PathCurvetoAbs();
    __PathCurvetoArgs();
    __PathCurvetoRel();
    __PathLinetoAbs();
    __PathLinetoHorizontalAbs();
    __PathLinetoHorizontalRel();
    __PathLinetoRel();
    __PathLinetoVerticalAbs();
    __PathLinetoVerticalRel();
    __PathMovetoAbs();
    __PathMovetoRel();
    __PathQuadraticCurvetoAbs();
    __PathQuadraticCurvetoArgs();
    __PathQuadraticCurvetoRel();
    __PathSmoothCurvetoAbs();
    __PathSmoothCurvetoRel();
    __PathSmoothQuadraticCurvetoAbs();
    __PathSmoothQuadraticCurvetoRel();
    __Pixels();
    __QuantumOperator();
    __QuantumType();
    __RenderingIntent();
    __ResolutionType();
    __SparseColorMethod();
    __StorageType();
    __StretchType();
    __StyleType();
    __STL();
    __TypeMetric();
    __VirtualPixelMethod();
    __gminfo();
}
